@charset "UTF-8";

/*! normalize.css v8.0.1 | MIT License | github.com/necolas/normalize.css */
/* Document
   ========================================================================== */
/**
 * 1. すべてのブラウザで line-height を修正.
 * 2. iOSで画面の向きを変更した際のフォントサイズの調整を防止.
 */
html {
  line-height: 1.15;
  /* 1 */
  -webkit-text-size-adjust: 100%;
  /* 2 */
}

/* Sections
   ========================================================================== */
/**
 * すべてのブラウザで margin を削除.
 */
body {
  margin: 0;
}

/**
 * IEで main 要素 を一貫してレンダリング.
 */
main {
  display: block;
}

/**
 * Chrome、Firefox、Safariにおいて section および article 内の h1 要素のフォントサイズと余白を修正.
 */
h1 {
  font-size: 2em;
  margin: 0.67em 0;
}

/* Grouping content
   ========================================================================== */
/**
 * 1. Firefoxで適切な box-sizing を設定する.
 * 2. Edge と IE で overflow を表示する.
 */
hr {
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
  /* 1 */
  height: 0;
  /* 1 */
  overflow: visible;
  /* 2 */
}

/**
 * 1. すべてのブラウザで、フォントサイズの継承とスケーリングを修正する.
 * 2. すべてのブラウザで、不自然な em 単位のフォントサイズを修正する.
 */
pre {
  font-family: monospace, monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */
}

/* Text-level semantics
   ========================================================================== */
/**
 * IE 10でアクティブなリンクのグレーの背景を削除する.
 */
a {
  background-color: transparent;
}

/**
 * 1. Chrome 57以降で下部の境界線を削除する
 * 2. Chrome、Edge、IE、Opera、およびSafariで適切なテキスト装飾を追加.
 */
abbr[title] {
  border-bottom: none;
  /* 1 */
  text-decoration: underline;
  /* 2 */
  -webkit-text-decoration: underline dotted;
  text-decoration: underline dotted;
  /* 2 */
}

/**
 * Chrome、Edge、Safariで適切なフォントウェイトを適用.
 */
b,
strong {
  font-weight: bolder;
}

/**
 * 1. Correct the inheritance and scaling of font size in all browsers.
 * 2. Correct the odd `em` font sizing in all browsers.
 */
code,
kbd,
samp {
  font-family: monospace, monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */
}

/**
 * Add the correct font size in all browsers.
 */
small {
  font-size: 80%;
}

/**
 * Prevent `sub` and `sup` elements from affecting the line height in
 * all browsers.
 */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sub {
  bottom: -0.25em;
}

sup {
  top: -0.5em;
}

/* Embedded content
   ========================================================================== */
/**
 * Remove the border on images inside links in IE 10.
 */
img {
  border-style: none;
}

/* Forms
   ========================================================================== */
/**
 * 1. Change the font styles in all browsers.
 * 2. Remove the margin in Firefox and Safari.
 */
button,
input,
optgroup,
select,
textarea {
  font-family: inherit;
  /* 1 */
  font-size: 100%;
  /* 1 */
  line-height: 1.15;
  /* 1 */
  margin: 0;
  /* 2 */
}

/**
 * Show the overflow in IE.
 * 1. Show the overflow in Edge.
 */
button,
input {
  /* 1 */
  overflow: visible;
}

/**
 * Remove the inheritance of text transform in Edge, Firefox, and IE.
 * 1. Remove the inheritance of text transform in Firefox.
 */
button,
select {
  /* 1 */
  text-transform: none;
}

/**
 * Correct the inability to style clickable types in iOS and Safari.
 */
button,
[type=button],
[type=reset],
[type=submit] {
  -webkit-appearance: button;
  -moz-appearance: button;
  appearance: button;
}

/**
 * Remove the inner border and padding in Firefox.
 */
button::-moz-focus-inner,
[type=button]::-moz-focus-inner,
[type=reset]::-moz-focus-inner,
[type=submit]::-moz-focus-inner {
  border-style: none;
  padding: 0;
}

/**
 * Restore the focus styles unset by the previous rule.
 */
button:-moz-focusring,
[type=button]:-moz-focusring,
[type=reset]:-moz-focusring,
[type=submit]:-moz-focusring {
  outline: 1px dotted ButtonText;
}

/**
 * Correct the padding in Firefox.
 */
fieldset {
  padding: 0.35em 0.75em 0.625em;
}

/**
 * 1. Correct the text wrapping in Edge and IE.
 * 2. Correct the color inheritance from `fieldset` elements in IE.
 * 3. Remove the padding so developers are not caught out when they zero out
 *    `fieldset` elements in all browsers.
 */
legend {
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  /* 1 */
  color: inherit;
  /* 2 */
  display: table;
  /* 1 */
  max-width: 100%;
  /* 1 */
  padding: 0;
  /* 3 */
  white-space: normal;
  /* 1 */
}

/**
 * Add the correct vertical alignment in Chrome, Firefox, and Opera.
 */
progress {
  vertical-align: baseline;
}

/**
 * Remove the default vertical scrollbar in IE 10+.
 */
textarea {
  overflow: auto;
}

/**
 * 1. Add the correct box sizing in IE 10.
 * 2. Remove the padding in IE 10.
 */
[type=checkbox],
[type=radio] {
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */
}

/**
 * Correct the cursor style of increment and decrement buttons in Chrome.
 */
[type=number]::-webkit-inner-spin-button,
[type=number]::-webkit-outer-spin-button {
  height: auto;
}

/**
 * 1. Correct the odd appearance in Chrome and Safari.
 * 2. Correct the outline style in Safari.
 */
[type=search] {
  -webkit-appearance: textfield;
  /* 1 */
  -moz-appearance: textfield;
  appearance: textfield;
  outline-offset: -2px;
  /* 2 */
}

/**
 * Remove the inner padding in Chrome and Safari on macOS.
 */
[type=search]::-webkit-search-decoration {
  -webkit-appearance: none;
}

/**
 * 1. Correct the inability to style clickable types in iOS and Safari.
 * 2. Change font properties to `inherit` in Safari.
 */
::-webkit-file-upload-button {
  -webkit-appearance: button;
  /* 1 */
  font: inherit;
  /* 2 */
}

/* Interactive
   ========================================================================== */
/*
 * Add the correct display in Edge, IE 10+, and Firefox.
 */
details {
  display: block;
}

/*
 * Add the correct display in all browsers.
 */
summary {
  display: list-item;
}

/* Misc
   ========================================================================== */
/**
 * Add the correct display in IE 10+.
 */
template {
  display: none;
}

/**
 * Add the correct display in IE 10.
 */
[hidden] {
  display: none;
}

* {
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

html {
  height: 100%;
}

body {
  padding: 0;
  width: 100%;
  height: 100%;
  overflow-x: hidden;
  font-family: "Noto Sans JP", sans-serif;
  font-weight: 400;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

a {
  text-decoration: none;
}

a:hover {
  opacity: 0.7;
}

a[href^="tel:"] {
  color: inherit;
  /* 親要素と同じ文字色にする */
  text-decoration: none;
  /* 下線を消す */
}

img {
  max-width: 100%;
  height: auto;
  vertical-align: middle;
}

h1,
h2,
h3 {
  font-weight: 400;
}

/* ヘッダー */
/* ==========================================================================
   PC向けレイアウト（初期値：横幅768px以上）
   ========================================================================== */
.l-header {
  /* background-color: darkseagreen; */
  border-bottom: 1px solid #515151;
}

.l-header-container {
  max-width: 1600px;
  width: 100%;
  margin: 0 auto;
}

/* ==========================================================================
   スマホ・タブレット向け調整（画面幅767px以下：ランドスケープ含む）
   ========================================================================== */
@media screen and (max-width: 767px) {
  .l-header {
    padding: 0 10px;
  }
}

/* フッター */
/* ==========================================================================
   PC向けレイアウト（初期値：横幅768px以上）
   ========================================================================== */
.l-footer {
  background-color: #2E59A7;
  color: #FFFFFF;
  padding-top: 40px;
  padding-bottom: 10px;
  background-image: url(../img/footer-logo-mrw.png);
  background-position: 90% center;
  background-size: contain;
  background-repeat: no-repeat;
}

/* ==========================================================================
   スマホ・タブレット向け調整（画面幅767px以下：ランドスケープ含む）
   ========================================================================== */
@media screen and (max-width: 767px) {
  .l-footer {
    padding: 0 10px;
  }
}

/* メイン */
/* ==========================================================================
   PC向けレイアウト（初期値：横幅768px以上）
   ========================================================================== */
.l-main {
  /*   background-color: bisque; */
}

/* ==========================================================================
   スマホ・タブレット向け調整（画面幅767px以下：ランドスケープ含む）
   ========================================================================== */
@media screen and (max-width: 767px) {
  .l-main {
    padding: 0 10px;
  }
}

.c-header {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  height: 130px;
}

.c-header__ttl {
  /*    background-color: chocolate; */
  height: 100%;
}

.c-header__menu {
  /*   background-color: aqua; */
  height: 100%;
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1;
  -ms-flex-negative: 0;
  flex-shrink: 0;
  -webkit-box-align: end;
  -ms-flex-align: end;
  align-items: end;
}

.c-header__menu__nav {
  /*    background-color: blueviolet; */
  height: 100%;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-align: end;
  -ms-flex-align: end;
  align-items: end;
}

.c-header__menu__nav__util {
  margin: 10px;
  padding: 0;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -ms-flex-pack: justify;
  justify-content: space-between;
  /*     background-color: blue; */
}

.c-header__menu__nav__util__item {
  display: inline-block;
  /*    background-color: aliceblue; */
  margin: 10px;
}

.c-header__menu__nav__util__item__a {
  display: block;
  width: 100%;
  padding: 5px 20px;
  color: #00175C;
  /*    font-weight: bold; */
  font-size: 14px;
}

.c-header__menu__nav__global {
  margin: 10px;
  padding: 0;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  /*    background-color: chartreuse; */
}

.c-header__menu__nav__global__item {
  display: inline-block;
  /*    background-color: aliceblue; */
  margin: 10px;
}

.c-header__menu__nav__global__item__a {
  display: block;
  width: 100%;
  padding: 5px 20px;
  color: #00175C;
  font-weight: bold;
  font-size: 20px;
}

.c-footer__main {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  width: 100%;
  max-width: 1400px;
  margin: 0 auto;
  padding: 20px;
  /*    background-color: rgb(48, 97, 202); */
  -webkit-box-pack: justify;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

.c-footer__main__menu {
  background-color: white;
  padding: 20px;
  border-radius: 10px;
}

.c-footer__main__menu__title {
  /*        background-color: #f3e7e7; */
  color: black;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin-bottom: 20px;
}

.c-footer__main__menu__title-img {
  /*        background-color: #c6e2b6;　*/
}

.c-footer__main__menu__title-txt {
  margin: 0;
  /*        background-color: #d9e992;　*/
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-pack: end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  font-size: 24px;
  font-weight: bold;
  color: #2E59A7;
  padding: 0 20px;
}

.c-footer__main__menu__block {
  /*    background-color: cornflowerblue; */
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

.c-footer__main__menu__block__nav {
  /*        background-color: rgb(211, 210, 197); */
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
}

.c-footer__main__menu__block__nav__ul {
  list-style: none;
  padding: 0;
  margin: 0 20px 0 0;
  line-height: 2.5rem;
}

.c-footer__main__menu__block__seal {
  /*        background-color: #E0E0E0; */
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1;
}

.c-footer__main__menu__block__seal__block {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: space-evenly;
  -ms-flex-pack: space-evenly;
  justify-content: space-evenly;
}

.c-footer__main__menu__block__seal__block-item {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: space-evenly;
  -ms-flex-pack: space-evenly;
  justify-content: space-evenly;
  -webkit-box-pack: center;
  -ms-flex-pack: center;
  justify-content: center;
  /* 横方向の中央揃え */
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center;
  /* 縦方向の中央揃え */
  -ms-flex-preferred-size: 120px;
  flex-basis: 120px;
}

.c-footer__main__menu a {
  color: #2E59A7;
  font-weight: bold;
}

.c-footer__main__address {
  /*    background-color: lightblue; */
  margin-left: 60px;
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1;
}

.c-footer__main__address-table {
  /*    background-color: rgb(163, 159, 194); */
  width: 100%;
}

.c-footer__main__address-table td {
  vertical-align: top;
  line-height: 1.5rem;
  height: 4rem;
}

.c-footer__links {
  width: 100%;
  max-width: 1400px;
  margin: 0 auto 20px auto;
}

.c-footer__links__item {
  display: inline-block;
  margin: 0 20px;
}

.c-footer__links__item a {
  color: #FFFFFF;
}

.c-footer__copy {
  margin-top: 20px;
  padding-top: 20px;
  border-top: 1px solid #FFFFFF;
  font-size: 12px;
}

.menu-wrap {
  max-width: 1400px;
  margin: 0 auto;
  background-color: #2E59A7;
  width: 100%;
}

.c-top__sec {
  max-width: 1400px;
  width: 100%;
  margin: 0 auto;
  padding: 40px 0;
}

.c-top__sec--mv {
  max-width: 1920px;
  margin-bottom: 0;
  padding-top: 0;
  padding-bottom: 0;
}

.c-top__sec--menu {
  margin-bottom: 100px;
  max-width: unset;
  background-color: #2E59A7;
}

.c-top__sec--menu__service {
  margin: 20px;
  padding: 20px;
  background-color: white;
  border: 4px solid #2E59A7;
  border-radius: 10px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -ms-flex-pack: justify;
  justify-content: space-between;
  margin-bottom: 60px;
}

.c-top__sec--menu__sales {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: center;
  -ms-flex-pack: center;
  justify-content: center;
  gap: 60px;
}

.c-top__sec--menu__sales__material {
  margin: 20px;
  padding: 20px;
  width: 100%;
  background-color: white;
  border: 4px solid #2E59A7;
  border-radius: 10px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -ms-flex-pack: justify;
  justify-content: space-between;
  -ms-flex-preferred-size: 80%;
  flex-basis: 80%;
}

.c-top__sec--menu__sales__machine {
  margin: 20px;
  padding: 20px;
  width: 100%;
  background-color: white;
  border: 4px solid #2E59A7;
  border-radius: 10px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -ms-flex-pack: justify;
  justify-content: space-between;
  -ms-flex-preferred-size: 80%;
  flex-basis: 80%;
}

.c-top__sec--menu__ttl {
  color: #00175C;
  font-weight: bold;
  font-size: 32px;
  margin-top: 10px;
}

.c-top__sec--msg {
  max-width: unset;
  background-color: #F2F8FF;
  margin-bottom: 100px;
}

.c-top__sec--company {
  max-width: unset;
  /*    background-color: #F2F8FF; */
}

.c-top__sec--news {
  /*    background-color: rgb(242, 243, 241); */
  max-width: 940px;
  /*    margin-bottom: 100px; */
}

.c-top__sec--news-ttl {
  width: 100%;
  text-align: center;
  padding: 0;
  color: #00175C;
  font-size: 32px;
  font-weight: bold;
  margin-bottom: 60px;
}

.c-top__sec--news-list {
  /*    background-color: blue; */
}

.c-top__sec--news-item {
  /*    background-color: aqua; */
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin-bottom: 40px;
  padding: 10px 0 20px 0;
  border-bottom: 2px solid #F0F0F0;
}

.c-top__sec--news-date {
  -ms-flex-preferred-size: 160px;
  flex-basis: 160px;
}

.c-top__sec--news-title a {
  color: #1C1C1C;
}

.c-top__sec--news-link {
  text-align: center;
}

.c-top__sec--news-link a {
  color: #1C1C1C;
}

.c-cta-container {
  background-color: #FFFFFF;
  width: 100%;
  max-width: 1000px;
  margin: 80px auto 100px auto;
  padding: 40px 20px;
  border: 4px solid #2E59A7;
  border-radius: 10px;
}

.c-cta-container__ttl {
  width: -webkit-fit-content;
  width: -moz-fit-content;
  width: fit-content;
  margin: 0 auto;
  font-size: 32px;
  font-weight: 600;
  color: #00175C;
}

.c-cta-container__btn {
  width: 100%;
  margin: 50px 0;
}

.c-cta-container__btn a {
  display: block;
  text-align: center;
  padding: 20px;
  background-color: #2E59A7;
  border-radius: 10px;
  width: 380px;
  margin: 20px auto 20px auto;
  color: #FFFFFF;
  font-weight: bold;
  font-size: 24px;
}

.c-cta-container__info {
  width: 100%;
  text-align: center;
  font-size: 18px;
  font-weight: 400;
}

.u-fs-8 {
  font-size: 8px;
}

.u-fs-10 {
  font-size: 10px;
}

.u-fs-12 {
  font-size: 12px;
}

.u-fs-14 {
  font-size: 14px;
}

.u-fs-15 {
  font-size: 15px;
}

.u-fs-16 {
  font-size: 16px;
}

.u-fs-18 {
  font-size: 18px;
}

.u-fs-20 {
  font-size: 20px;
}

.u-fs-24 {
  font-size: 24px;
}

.u-fs-25 {
  font-size: 25px;
}

.u-fs-26 {
  font-size: 26px;
}

.u-fs-28 {
  font-size: 28px;
}

.u-fs-30 {
  font-size: 30px;
}

.u-fs-32 {
  font-size: 32px;
}

.u-fw-un {
  font-weight: unset;
}

.u-fw-bo {
  font-weight: bold;
}

.u-m-0 {
  margin: 0;
}

.u-mt-0 {
  margin-top: 0;
}

.u-mt-5 {
  margin-top: 5px;
}

.u-mt-10 {
  margin-top: 10px;
}

.u-mt-20 {
  margin-top: 20px;
}

.u-mt-30 {
  margin-top: 30px;
}

.u-mt-40 {
  margin-top: 40px;
}

.u-mt-50 {
  margin-top: 50px;
}

.u-mt-60 {
  margin-top: 60px;
}

.u-mt-80 {
  margin-top: 80px;
}

.u-mt-100 {
  margin-top: 100px;
}

.u-mr-0 {
  margin-right: 0;
}

.u-mr-5 {
  margin-right: 5px;
}

.u-mr-10 {
  margin-right: 10px;
}

.u-mr-20 {
  margin-right: 20px;
}

.u-mr-30 {
  margin-right: 30px;
}

.u-mr-40 {
  margin-right: 40px;
}

.u-mr-50 {
  margin-right: 50px;
}

.u-mr-60 {
  margin-right: 60px;
}

.u-mr-80 {
  margin-right: 80px;
}

.u-mr-100 {
  margin-right: 100px;
}

.u-mb-0 {
  margin-bottom: 0;
}

.u-mb-5 {
  margin-bottom: 5px;
}

.u-mb-10 {
  margin-bottom: 10px;
}

.u-mb-20 {
  margin-bottom: 20px;
}

.u-mb-30 {
  margin-bottom: 30px;
}

.u-mb-40 {
  margin-bottom: 40px;
}

.u-mb-50 {
  margin-bottom: 50px;
}

.u-mb-60 {
  margin-bottom: 60px;
}

.u-mb-80 {
  margin-bottom: 80px;
}

.u-mb-100 {
  margin-bottom: 100px;
}

.u-co-gray1 {
  color: #F0F0F0;
}

.u-co-gray2 {
  color: #707070;
}

.u-ff-serif {
  font-family: "游明朝体", "Yu Mincho", "游明朝", "YuMincho", serif;
}

.u-ta-c {
  text-align: center;
}

.u-ta-l {
  text-align: left;
}

.u-ta-r {
  text-align: right;
}

@media screen and (min-width: 768px) {
  .u-hide-pc {
    display: none;
  }
}

@media screen and (max-width: 767px) {
  .u-hide-sp {
    display: none;
  }
}

@media screen and (max-width: 479px) {
  .u-hide-sp-port {
    display: none;
  }
}

/*# sourceMappingURL=style.css.map */


/*  ハードコーディング　*/

.l-main--page {
  width: 100%;
  max-width: 1200px;
  margin: 0 auto;
}

.network {
  background-image: url(../img/bg-img-network.png);
  background-position: center;
  background-size: cover;

}

.network img {
  display: block;
  width: 100%;
  max-width: 1200px;
  margin: 0 auto;
  padding: 40px 0;
}